@@ -1,3 +1,3 @@
 from . import word
 from . import pdf
-from . import email
\ No newline at end of file
+from . import image
\ No newline at end of file
